==> kubernetes-model-gatewayapi-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/RouteParentStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.model.Condition;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RouteParentStatusFluentImpl<A extends RouteParentStatusFluent<A>> extends BaseFluent<A> implements RouteParentStatusFluent<A>{
  public RouteParentStatusFluentImpl() {
  }
  public RouteParentStatusFluentImpl(RouteParentStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withControllerName(instance.getControllerName()); 
    this.withParentRef(instance.getParentRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private List<Condition> conditions = new ArrayList<Condition>();
  private String controllerName;
  private ParentReferenceBuilder parentRef;
  private Map<String,Object> additionalProperties;
  public A addToConditions(Integer index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.add(index, item);
    return (A)this;
  }
  public A setToConditions(Integer index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.set(index, item); return (A)this;
  }
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A addAllToConditions(Collection<Condition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<Condition> items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public List<Condition> getConditions() {
    return this.conditions;
  }
  public Condition getCondition(Integer index) {
    return this.conditions.get(index);
  }
  public Condition getFirstCondition() {
    return this.conditions.get(0);
  }
  public Condition getLastCondition() {
    return this.conditions.get(conditions.size() - 1);
  }
  public Condition getMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<Condition> conditions) {
    if (conditions != null) {this.conditions = new ArrayList(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public String getControllerName() {
    return this.controllerName;
  }
  public A withControllerName(String controllerName) {
    this.controllerName=controllerName; return (A) this;
  }
  public Boolean hasControllerName() {
    return this.controllerName != null;
  }
  
  /**
   * This method has been deprecated, please use method buildParentRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParentReference getParentRef() {
    return this.parentRef!=null ?this.parentRef.build():null;
  }
  public ParentReference buildParentRef() {
    return this.parentRef!=null ?this.parentRef.build():null;
  }
  public A withParentRef(ParentReference parentRef) {
    _visitables.get("parentRef").remove(this.parentRef);
    if (parentRef!=null){ this.parentRef= new ParentReferenceBuilder(parentRef); _visitables.get("parentRef").add(this.parentRef);} else { this.parentRef = null; _visitables.get("parentRef").remove(this.parentRef); } return (A) this;
  }
  public Boolean hasParentRef() {
    return this.parentRef != null;
  }
  public RouteParentStatusFluent.ParentRefNested<A> withNewParentRef() {
    return new RouteParentStatusFluentImpl.ParentRefNestedImpl();
  }
  public RouteParentStatusFluent.ParentRefNested<A> withNewParentRefLike(ParentReference item) {
    return new RouteParentStatusFluentImpl.ParentRefNestedImpl(item);
  }
  public RouteParentStatusFluent.ParentRefNested<A> editParentRef() {
    return withNewParentRefLike(getParentRef());
  }
  public RouteParentStatusFluent.ParentRefNested<A> editOrNewParentRef() {
    return withNewParentRefLike(getParentRef() != null ? getParentRef(): new ParentReferenceBuilder().build());
  }
  public RouteParentStatusFluent.ParentRefNested<A> editOrNewParentRefLike(ParentReference item) {
    return withNewParentRefLike(getParentRef() != null ? getParentRef(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RouteParentStatusFluentImpl that = (RouteParentStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (controllerName != null ? !controllerName.equals(that.controllerName) :that.controllerName != null) return false;
    if (parentRef != null ? !parentRef.equals(that.parentRef) :that.parentRef != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  controllerName,  parentRef,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (controllerName != null) { sb.append("controllerName:"); sb.append(controllerName + ","); }
    if (parentRef != null) { sb.append("parentRef:"); sb.append(parentRef + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ParentRefNestedImpl<N> extends ParentReferenceFluentImpl<RouteParentStatusFluent.ParentRefNested<N>> implements RouteParentStatusFluent.ParentRefNested<N>,Nested<N>{
    ParentRefNestedImpl(ParentReference item) {
      this.builder = new ParentReferenceBuilder(this, item);
    }
    ParentRefNestedImpl() {
      this.builder = new ParentReferenceBuilder(this);
    }
    ParentReferenceBuilder builder;
    public N and() {
      return (N) RouteParentStatusFluentImpl.this.withParentRef(builder.build());
    }
    public N endParentRef() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/RouteParentStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.model.Condition;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RouteParentStatusFluentImpl<A extends RouteParentStatusFluent<A>> extends BaseFluent<A> implements RouteParentStatusFluent<A>{
  public RouteParentStatusFluentImpl() {
  }
  public RouteParentStatusFluentImpl(RouteParentStatus instance) {
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withControllerName(instance.getControllerName());
      this.withParentRef(instance.getParentRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private List<Condition> conditions = new ArrayList<Condition>();
  private String controllerName;
  private ParentReferenceBuilder parentRef;
  private Map<String,Object> additionalProperties;
  public A addToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.add(index, item);
    return (A)this;
  }
  public A setToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    this.conditions.set(index, item); return (A)this;
  }
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A addAllToConditions(Collection<Condition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<Condition>();}
    for (Condition item : items) {this.conditions.add(item);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<Condition> items) {
    for (Condition item : items) {if (this.conditions!= null){ this.conditions.remove(item);}} return (A)this;
  }
  public List<Condition> getConditions() {
    return this.conditions;
  }
  public Condition getCondition(int index) {
    return this.conditions.get(index);
  }
  public Condition getFirstCondition() {
    return this.conditions.get(0);
  }
  public Condition getLastCondition() {
    return this.conditions.get(conditions.size() - 1);
  }
  public Condition getMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<Condition> predicate) {
    for (Condition item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<Condition> conditions) {
    if (conditions != null) {this.conditions = new ArrayList(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public String getControllerName() {
    return this.controllerName;
  }
  public A withControllerName(String controllerName) {
    this.controllerName=controllerName; return (A) this;
  }
  public Boolean hasControllerName() {
    return this.controllerName != null;
  }
  
  /**
   * This method has been deprecated, please use method buildParentRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParentReference getParentRef() {
    return this.parentRef!=null ?this.parentRef.build():null;
  }
  public ParentReference buildParentRef() {
    return this.parentRef!=null ?this.parentRef.build():null;
  }
  public A withParentRef(ParentReference parentRef) {
    _visitables.get("parentRef").remove(this.parentRef);
    if (parentRef!=null){ this.parentRef= new ParentReferenceBuilder(parentRef); _visitables.get("parentRef").add(this.parentRef);} else { this.parentRef = null; _visitables.get("parentRef").remove(this.parentRef); } return (A) this;
  }
  public Boolean hasParentRef() {
    return this.parentRef != null;
  }
  public RouteParentStatusFluentImpl.ParentRefNested<A> withNewParentRef() {
    return new RouteParentStatusFluentImpl.ParentRefNestedImpl();
  }
  public RouteParentStatusFluentImpl.ParentRefNested<A> withNewParentRefLike(ParentReference item) {
    return new RouteParentStatusFluentImpl.ParentRefNestedImpl(item);
  }
  public RouteParentStatusFluentImpl.ParentRefNested<A> editParentRef() {
    return withNewParentRefLike(getParentRef());
  }
  public RouteParentStatusFluentImpl.ParentRefNested<A> editOrNewParentRef() {
    return withNewParentRefLike(getParentRef() != null ? getParentRef(): new ParentReferenceBuilder().build());
  }
  public RouteParentStatusFluentImpl.ParentRefNested<A> editOrNewParentRefLike(ParentReference item) {
    return withNewParentRefLike(getParentRef() != null ? getParentRef(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteParentStatusFluentImpl that = (RouteParentStatusFluentImpl) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;

    if (!java.util.Objects.equals(controllerName, that.controllerName)) return false;

    if (!java.util.Objects.equals(parentRef, that.parentRef)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  controllerName,  parentRef,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (controllerName != null) { sb.append("controllerName:"); sb.append(controllerName + ","); }
    if (parentRef != null) { sb.append("parentRef:"); sb.append(parentRef + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ParentRefNestedImpl<N> extends ParentReferenceFluentImpl<RouteParentStatusFluentImpl.ParentRefNested<N>> implements RouteParentStatusFluentImpl.ParentRefNested<N>,Nested<N>{
    ParentRefNestedImpl(ParentReference item) {
      this.builder = new ParentReferenceBuilder(this, item);
    }
    ParentRefNestedImpl() {
      this.builder = new ParentReferenceBuilder(this);
    }
    ParentReferenceBuilder builder;
    public N and() {
      return (N) RouteParentStatusFluentImpl.this.withParentRef(builder.build());
    }
    public N endParentRef() {
      return and();
    }
    
  }
  
}
